==> apache-camel-2.23.4-src.zip: apache-camel-2.23.4/components/camel-spring/src/test/java/org/apache/camel/spring/processor/SpringSetHeaderNameDynamicTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.spring.processor;

import org.apache.camel.CamelContext;
import org.apache.camel.ContextTestSupport;
import org.apache.camel.Exchange;
import org.apache.camel.component.mock.MockEndpoint;
import org.junit.Test;

import static org.apache.camel.spring.processor.SpringTestHelper.createSpringCamelContext;

public class SpringSetHeaderNameDynamicTest extends ContextTestSupport {


    @Test
    public void testSetHeaderNameWithExpression() throws Exception {
        MockEndpoint resultEndpoint = getMockEndpoint("mock:end");
        resultEndpoint.expectedMessageCount(1);

        sendBody("direct:start", "Hello");

        resultEndpoint.assertIsSatisfied();

        Exchange exchange = resultEndpoint.getExchanges().get(0);

        assertEquals(Boolean.TRUE, exchange.getIn().getHeader(SpringSetPropertyNameDynamicTest.TestConstans
                .EXCHANGE_PROP_TX_FAILED, Boolean.class));
    }

    protected CamelContext createCamelContext() throws Exception {
        return createSpringCamelContext(this, "org/apache/camel/spring/processor/setHeaderNameDynamic.xml");
    }
}

==> apache-camel-3.4.6-src.zip: apache-camel-3.4.6/components/camel-spring/src/test/java/org/apache/camel/spring/processor/SpringSetHeaderNameDynamicTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.spring.processor;

import org.apache.camel.CamelContext;
import org.apache.camel.ContextTestSupport;
import org.apache.camel.Exchange;
import org.apache.camel.component.mock.MockEndpoint;
import org.junit.jupiter.api.Test;

import static org.apache.camel.spring.processor.SpringTestHelper.createSpringCamelContext;
import static org.junit.jupiter.api.Assertions.assertEquals;

public class SpringSetHeaderNameDynamicTest extends ContextTestSupport {


    @Test
    public void testSetHeaderNameWithExpression() throws Exception {
        MockEndpoint resultEndpoint = getMockEndpoint("mock:end");
        resultEndpoint.expectedMessageCount(1);

        sendBody("direct:start", "Hello");

        resultEndpoint.assertIsSatisfied();

        Exchange exchange = resultEndpoint.getExchanges().get(0);

        assertEquals(Boolean.TRUE, exchange.getIn().getHeader(SpringSetPropertyNameDynamicTest.TestConstans
                .EXCHANGE_PROP_TX_FAILED, Boolean.class));
    }

    @Override
    protected CamelContext createCamelContext() throws Exception {
        return createSpringCamelContext(this, "org/apache/camel/spring/processor/setHeaderNameDynamic.xml");
    }
}
